@@ -4,7 +4,7 @@ use warnings;
 
 package App::MP4Meta::Command::film;
 {
-  $App::MP4Meta::Command::film::VERSION = '1.130420';
+  $App::MP4Meta::Command::film::VERSION = '1.153340';
 }
 
 # ABSTRACT: Apply metadata to a film. Parses the filename in order to get the films title and (optionally) year.
@@ -24,7 +24,7 @@ sub opt_spec {
     return (
         [ "genre=s",     "The genre of the Film" ],
         [ "coverfile=s", "The location of the cover image" ],
-        [ "sources=s@", "The sources to search", { default => [qw/IMDB/] } ],
+        [ "sources=s@", "The sources to search", { default => [qw/OMDB/] } ],
         [ "title=s",    "The title of the Film" ],
         [ "noreplace", "Don't replace the file - creates a temp file instead" ],
         [ "itunes",  "adds to iTunes after applying meta data. Mac OSX only." ],
@@ -92,15 +92,18 @@ sub execute {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::MP4Meta::Command::film - Apply metadata to a film. Parses the filename in order to get the films title and (optionally) year.
 
 =head1 VERSION
 
-version 1.130420
+version 1.153340
 
 =head1 SYNOPSIS
 
@@ -110,7 +113,7 @@ version 1.130420
 
 This command applies metadata to one or more films. It parses the filename in order to get the films title and (optionally) year.
 
-It gets the films metadata by querying the IMDB. It then uses AtomicParsley to apply the metadata to the file.
+It gets the films metadata by querying the OMDB. It then uses AtomicParsley to apply the metadata to the file.
 
 By default, it will apply the metadata to the existing file. If you want it to write to a temporary file and leave the existing file untouched, provide the C<--noreplace> option.
 
@@ -120,10 +123,9 @@ Andrew Jones <andrew@arjones.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Andrew Jones.
+This software is copyright (c) 2015 by Andrew Jones.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
