@@ -4,7 +4,7 @@ use warnings;
 
 package App::MP4Meta::TV;
 {
-  $App::MP4Meta::TV::VERSION = '1.130420';
+  $App::MP4Meta::TV::VERSION = '1.153340';
 }
 
 # ABSTRACT: Add metadata to a TV Series
@@ -20,12 +20,19 @@ use App::MP4Meta::Source::Data::TVEpisode;
 # a list of regexes to try to parse the file
 my @file_regexes = (
     qr/^S(?<season>\d)-E(?<episode>\d)\s+-\s+(?<show>.*)$/,
+    qr/^S(?<season>\d)-E(?<episode>\d)\s*-\s*E(?<end_episode>\d)\s+-\s+(?<show>.*)$/,
     qr/^(?<show>.*)\s+S(?<season>\d\d)(\s|)E(?<episode>\d\d)$/,
+    qr/^(?<show>.*)\s+S(?<season>\d\d)(\s|)E(?<episode>\d\d)\s*-\s*E(?<end_episode>\d\d)$/,
     qr/^(?<show>.*)\.S(?<season>\d\d)E(?<episode>\d\d)/i,
+    qr/^(?<show>.*)\.S(?<season>\d\d)E(?<episode>\d\d)\s*-\s*E(?<end_episode>\d\d)/i,
     qr/^(?<show>.*)\s*-?\s*S(?<season>\d\d?)E(?<episode>\d\d?)/i,
+    qr/^(?<show>.*)\s*-?\s*S(?<season>\d\d?)E(?<episode>\d\d?)\s*-\s*E(?<end_episode>\d\d)/i,
     qr/^(?<show>.*)-S(?<season>\d\d?)E(?<episode>\d\d?)/,
-    qr/^(?<show>.*)_S(?<season>\d\d?)E(?<episode>\d\d?)/,
-    qr/S(?<season>\d\d?)E(?<episode>\d\d?)/,
+    qr/^(?<show>.*)-S(?<season>\d\d?)E(?<episode>\d\d?)\s*-\s*E(?<end_episode>\d\d)/,
+    qr/^(?<show>.*)-S(?<season>\d\d?)E(?<episode>\d\d?)/i,
+    qr/^(?<show>.*)-S(?<season>\d\d?)E(?<episode>\d\d?)\s*-\s*E(?<end_episode>\d\d)/i,
+    qr/S(?<season>\d\d?)E(?<episode>\d\d?)/i,
+    qr/S(?<season>\d\d?)E(?<episode>\d\d?)\s*-\s*E(?<end_episode>\d\d?)/i,
     qr/^(?<show>.*)\s*-?\s*(?<season>\d\d?)x(?<episode>\d\d?)/,
 );
 
@@ -70,7 +77,7 @@ sub apply_meta {
 
         # parse the filename for the title, season and episode
         ( $tags{show_title}, $tags{season}, $tags{episode} ) =
-          $self->_parse_filename($file);
+          $self->_parse_filename($file, $directories);
         unless ( $tags{show_title} && $tags{season} && $tags{episode} ) {
             return "Error: could not parse the filename for $path";
         }
@@ -137,7 +144,11 @@ sub apply_meta {
 
 # Parse the filename in order to get the series title the and season and episode number.
 sub _parse_filename {
-    my ( $self, $file ) = @_;
+    my ( $self, $file, $directories ) = @_;
+
+    my $show = '';
+    my $season = '';
+    my $episode = '';
 
     # strip suffix
     $file = $self->_strip_suffix($file);
@@ -145,9 +156,9 @@ sub _parse_filename {
     # see if we have a regex that matches
     for my $r (@file_regexes) {
         if ( $file =~ $r ) {
-            my $show    = $self->{title}   // $+{show};
-            my $season  = $self->{season}  // $+{season};
-            my $episode = $self->{episode} // $+{episode};
+            $show       = $self->{title}   // $+{show};
+            $season  = $self->{season}  // $+{season};
+            $episode = $self->{episode} // $+{episode};
 
             if ( $show && $season && $episode ) {
 
@@ -157,6 +168,17 @@ sub _parse_filename {
         }
     }
 
+    if ( $directories )
+    {
+        #-- remove Season N
+        $directories =~ s{/season\s+(\d+)$/?}{}i;
+        my @parts = (split /\//, $directories);
+        $show = $parts[$#parts];
+    }
+    
+    if ( $show && $season && $episode ) {
+        return ( $self->_clean_title($show), int $season, int $episode );
+    }
     return;
 }
 
@@ -171,17 +193,19 @@ sub _episode_is_complete {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::MP4Meta::TV - Add metadata to a TV Series
 
 =head1 VERSION
 
-version 1.130420
+version 1.153340
 
 =head1 SYNOPSIS
 
@@ -202,10 +226,9 @@ Andrew Jones <andrew@arjones.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Andrew Jones.
+This software is copyright (c) 2015 by Andrew Jones.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
